*{
    overflow: hidden;
    color: azure;
}

.login-container{
    width: 100%;
    margin: 0;
    top: 0;
    align-items: center;
    display: grid;
    justify-content: center;
    background-color: darkcyan;
}

.login{
    width: 100%;
    height: 100vh;
    margin: 10px;
    padding: 20px;
    align-items: center;
    justify-content: space-between;
    
}

.login-card{
    width: 100%;
    height: 100vh;
    display: grid;
    padding: 20px;
    align-items: center;
    justify-content: space-between;
}

.login-card form{
    display: grid;
}

.login-card .image {
    text-align: center;
    display: block;

}

.logout-card{
    width: 100%;
    height: 100vh;
    display: flex;
    padding: 20px;
    align-items: center;
    justify-content: space-around;
    gap: 50px;
}

.logout-card form{
    display: grid;
    align-items: center;
    justify-content: space-around;
}

.logout-card .image {
    
    display: block;


}