# Generated by Django 3.2.12 on 2023-02-01 18:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptions', '0012_alter_subscription_subscription_duration'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='plan',
            options={'ordering': ('-price',)},
        ),
        migrations.AlterModelOptions(
            name='productfeature',
            options={'ordering': ('-pk',)},
        ),
        migrations.AlterModelOptions(
            name='subscription',
            options={'ordering': ('-last_updated',), 'verbose_name': 'Subscription'},
        ),
    ]
