{% load static %}
{% load i18n helpdesk_staff %}
<!-- Right navbar links -->
<ul class="navbar-nav ml-auto">
    <!-- Messages Dropdown Menu -->

    <!-- Notifications Dropdown Menu -->
    {%if user.type == "Admin"%}
    <li class="nav-item dropdown">
        <a class="nav-link" data-toggle="dropdown" href="#">
            <i class="fas fa-cogs"></i>
        </a>
        <div class="dropdown-menu dropdown-menu-sm dropdown-menu-right">
            <a href="{% url 'pinax_teams:team_list'%} " class="dropdown-item">
                <i class="fas fa-envelope mr-2"></i> Teams
            </a>
            <div class="dropdown-divider"></div>
            <a href="{% url 'update_address' %}" class="dropdown-item">
                <i class="fas fa-map-marker mr-2"></i> Address

            </a>
            <div class="dropdown-divider"></div>
            <a href="{% url 'update_info' %}" class="dropdown-item">
                <i class="fas fa-file mr-2"></i> Company Details
            </a>
            <!-- <div class="dropdown-divider"></div>
            <a href="{#% url 'manage_tlds'%#}" class="dropdown-item">
                <i class="fas fa-globe mr-2"></i>View TLD's
            </a> -->
            <div class="dropdown-divider"></div>
            <a href="{% url 'plan_list'%}" class="dropdown-item">
                <i class="fas fa-list-ol mr-2"></i>View Plans
            </a>
            <!-- <div class="dropdown-divider"></div>
            <a href="{#% url 'product_list'%#}" class="dropdown-item">
                <i class="fas fa-gift mr-2"></i>View Products
            </a>
            
            <div class="dropdown-divider"></div>
            <a href="{#% url 'accounts_manager' %#}" class="dropdown-item">
                <i class="fas fa-users mr-2"></i> Accounts Manager
            </a> -->
            <div class="dropdown-divider"></div>
            <a href="{% url 'settings_index'%}" class="dropdown-item dropdown-footer">All Settings</a>
        </div>
    </li>
    {%endif%}
    <li class="nav-item dropdown">
        <a class="nav-link" data-toggle="dropdown" href="#">
            <i class="fas fa-globe"></i>
        </a>
        <div class="dropdown-menu dropdown-menu-sm dropdown-menu-right">
            <a href="{% url 'pinax_teams:team_list'%} " class="dropdown-item">
                English
            </a>
            <div class="dropdown-divider"></div>
            <a href="{% url 'update_address' %}" class="dropdown-item">
                Swahili

            </a>
            <div class="dropdown-divider"></div>
            <a href="{% url 'update_info' %}" class="dropdown-item">
                Spanish
            </a>


        </div>
    </li>


</ul>




<ul class="navbar-nav ml-auto">
    <li class="nav-item dropdown ">
        <a class="nav-link dropdown-toggle" href="#" id="userDropdown" role="button" data-toggle="dropdown"
            aria-haspopup="true" aria-expanded="false">
            <i class="fas fa-user-circle fa-fw"></i>
            {{ user.get_full_name|default:user.get_username }}

        </a>
        <div class="dropdown-menu dropdown-menu-right" aria-labelledby="userDropdown">
            {%if user.is_staff %}
            <a href="{% url 'profiles_detail' username=user.username %}" class="dropdown-item">
                <i class="fas fa-user mr-2"></i> Profile
            </a>
            <div class="dropdown-divider"></div>
            {%endif%}
            <a href="{% url 'account_settings'  %}" class="dropdown-item">
                <i class="fas fas fa-user-edit mr-2"></i> Account
            </a>
            <div class="dropdown-divider"></div>
            {% if helpdesk_settings.HELPDESK_NAVIGATION_ENABLED and user.is_authenticated or user|is_helpdesk_staff %}
            <a class="dropdown-item" href="{% url 'helpdesk:user_settings' %}"><i class="fas fa-fw fa-user-cog"></i>
                {% trans "User Settings" %}</a>
            <a class="dropdown-item" href='{% url 'helpdesk:rss_index' %}'><i class="fas fa-fw fa-rss-square"></i>
                {% trans "RSS Feeds" %}</a>
            {% if helpdesk_settings.HELPDESK_SHOW_CHANGE_PASSWORD and user.has_usable_password %}
            <a class="dropdown-item" href="{% url 'helpdesk:password_change' %}"><i
                    class="fas fa-fw fa-user-secret"></i> {% trans "Change password" %}</a>
            {% endif %}
            <div class="dropdown-divider"></div>
            {% if user.is_superuser %}
            <a class="dropdown-item" href='{% url 'helpdesk:system_settings' %}'><i class="fas fa-fw fa-cogs"></i>
                {% trans "System Settings" %}</a>
            <div class="dropdown-divider"></div>
            {% endif %}
            {% endif %}
            <a class="dropdown-item" href="{% url 'account_logout' %}"><i class="fas fa-fw fa-sign-out-alt"></i>
                {% trans "Logout" %}</a>
        </div>
    </li>




</ul>