# Generated by Django 3.2.12 on 2023-01-01 04:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptions', '0004_auto_20221113_1106'),
    ]

    operations = [
        migrations.AlterField(
            model_name='plan',
            name='name',
            field=models.CharField(choices=[('personal', 'personal'), ('premium', 'premium'), ('business', 'business')], max_length=250, unique=True),
        ),
    ]
