# Generated by Django 3.2.12 on 2023-01-08 13:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptions', '0008_auto_20230108_1539'),
    ]

    operations = [
        migrations.AlterField(
            model_name='plan',
            name='slug',
            field=models.SlugField(),
        ),
    ]
