# Generated by Django 3.2.12 on 2022-12-10 13:24

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptions', '0004_auto_20221113_1106'),
        ('apps', '0009_domain_has_custom'),
    ]

    operations = [
        migrations.DeleteModel(
            name='TenantType',
        ),
        migrations.RemoveField(
            model_name='tenant',
            name='subscription',
        ),
        migrations.AlterField(
            model_name='tenant',
            name='on_trial',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='tenant',
            name='plan',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.PROTECT, to='subscriptions.plan'),
        ),
        migrations.DeleteModel(
            name='Package',
        ),
    ]
