{% load multitenancy_tags %}
{% get_company_details as details %}
<footer class="main-footer text-center" >
    <strong class="text-center">Copyright &copy; <script>document.write(new Date().getFullYear())</script> <a href="{{details.info.website}}">{{details.info.company_name}}</a>.</strong>
    All rights reserved.
    <div class="float-right d-none d-sm-inline-block">

    </div>
</footer>