# Generated by Django 3.2.12 on 2022-11-21 15:58

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('settings', '0005_auto_20221116_1150'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='adminsettings',
            options={'verbose_name': 'Time zone and currency'},
        ),
    ]
