# Generated by Django 3.2.12 on 2023-01-24 17:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('settings', '0006_alter_adminsettings_options'),
    ]

    operations = [
        migrations.AlterField(
            model_name='logo',
            name='logo',
            field=models.ImageField(default='core/logo.png', upload_to=''),
        ),
    ]
