{% extends "account/base.html" %}

{% load i18n %}
{% load bootstrap4 %}
{% load account_tags %}

{% block head_title %}{% trans "Password reset" %}{% endblock %}

{% user_display request.user as user_display %}

{% block content %}
    
    <div class="row">
        <div class="col  m-0">
            <div class="login-box login m-0">
                <div class="login-card">
                    <div class="image"> 
                        <img src="{{details.logo.logo.url}}" href="{{details.info.website.url}}" height="100px" style="align-self: center; margin-bottom: 20px;" class="" alt="">
                    </div> 
                    <form method="POST" action="{% url "accounts_login" %}" autocapitalize="off" {% if form.is_multipart %} enctype="multipart/form-data"{% endif %}>
                        <legend class="">{% trans "Log in to an existing account" %}</legend>
    
                        {% csrf_token %}
                        {% bootstrap_form form %}
                        {% if redirect_field_value %}
                        <input type="hidden" name="{{ redirect_field_name }}" value="{{ redirect_field_value }}" />
                    {% endif %}
                    <button type="submit" class="btn btn-primary">
                        {% trans "Reset my password" %}
                    </button>
                    </form>
                    <p>{% blocktrans %}If you have any trouble resetting your password, contact us at <a href="mailto:{{ THEME_CONTACT_EMAIL }}">{{ THEME_CONTACT_EMAIL }}</a>.{% endblocktrans %}</p>
                </div>
            </div>
        </div>
        <!-- <div class="col-md-6 bg-dark">
            {#% include "account/_login_sidebar.html" %#}
        </div> -->
    </div>
    
       
{% endblock %}

{% block extra_body %}
    <script>
        $("#id_email").focus();
    </script>
{% endblock %}