# Generated by Django 3.2.12 on 2023-02-08 06:04

from django.db import migrations, models
import phonenumber_field.modelfields


class Migration(migrations.Migration):

    dependencies = [
        ('settings', '0007_alter_logo_logo'),
    ]

    operations = [
        migrations.AlterField(
            model_name='generalinfo',
            name='company_name',
            field=models.CharField(blank=True, default='Django Multitenancy', max_length=255),
        ),
        migrations.AlterField(
            model_name='generalinfo',
            name='phone_number',
            field=phonenumber_field.modelfields.PhoneNumberField(blank=True, default='+27212345678', max_length=128, region=None),
        ),
        migrations.AlterField(
            model_name='generalinfo',
            name='website',
            field=models.URLField(blank=True, default='example.com'),
        ),
    ]
