{% extends "account/base.html" %}
{% load i18n %}
{%block head_title%}{%trans "Page Not Found" %}{%endblock%}

{% block content %}
<div class="row">
    <div class="col m-0">
        <div class="login-box login m-0">
            <div class="logout-card">
                <div class="image"> 
                    <img src="{{details.logo.logo.url}}" href="{{details.info.website.url}}" height="200px"  class="" alt="">
                </div> 
                <h1>Page Not Found</h1>
                
            </div>
        </div>
    </div>
    <!-- <div class="col-md-6 bg-dark">
        {#% include "account/_login_sidebar.html" %#}
    </div> -->
</div>
{%endblock%}