# Generated by Django 3.2.12 on 2023-01-24 17:49

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptions', '0009_alter_plan_slug'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='subscription',
            name='renewal_status',
        ),
        migrations.AlterField(
            model_name='subscription',
            name='product_type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='subscriptions', to='subscriptions.producttype'),
        ),
        migrations.AlterField(
            model_name='subscription',
            name='status',
            field=models.CharField(choices=[('active', 'Active'), ('inactive', 'Inactive'), ('cancelled', 'Cancelled'), ('expired', 'Expired')], default='inactive', max_length=10),
        ),
    ]
