# Generated by Django 3.2.12 on 2022-11-12 05:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('apps', '0004_rename_packages_package'),
    ]

    operations = [
        migrations.AlterField(
            model_name='tenanttype',
            name='name',
            field=models.CharField(choices=[('public', 'public'), ('personal', 'personal'), ('premium', 'premium'), ('business', 'business')], default='personal', max_length=150),
        ),
    ]
