# Generated by Django 3.2.12 on 2023-02-03 15:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptions', '0013_auto_20230201_2059'),
    ]

    operations = [
        migrations.AddField(
            model_name='subscription',
            name='created_date',
            field=models.DateField(auto_now_add=True, null=True),
        ),
    ]
