# Generated by Django 3.2.12 on 2022-11-15 17:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('settings', '0003_auto_20221115_1846'),
    ]

    operations = [
        migrations.AddField(
            model_name='address',
            name='slug',
            field=models.SlugField(null=True),
        ),
        migrations.AddField(
            model_name='generalinfo',
            name='slug',
            field=models.SlugField(null=True),
        ),
    ]
