


.slow{
    transition: ease-in-out;
    transform-origin: right;
    transition-duration: 3s;
    transition: all;
}

.loadingSpinnerContainer {
    position: absolute;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    background-color: rgb(157, 23, 77, 1);
    z-index: 5000;
    display: flex;
    flex-direction: column;
    gap: 2rem;
    justify-content: center;
    align-items: center;
  }
  
  .loadingSpinner {
    width: 64px;
    height: 64px;
    margin: 0;
    border: 8px solid;
    border-color: #000 transparent rgb(255, 255, 255) transparent;
    border-radius: 50%;
    animation: spin 1.2s linear infinite;
  }
  
  @keyframes spin {
    0% {
      transform: rotate(0deg);
    }
    100% {
      transform: rotate(360deg);
    }
  }
