# Generated by Django 3.2.12 on 2022-12-08 08:33

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('apps', '0007_tenant_subscription'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='registereddomain',
            name='owner',
        ),
        migrations.RemoveField(
            model_name='registereddomain',
            name='tld',
        ),
        migrations.RemoveField(
            model_name='domain',
            name='dns',
        ),
        migrations.DeleteModel(
            name='DomainTld',
        ),
        migrations.DeleteModel(
            name='RegisteredDomain',
        ),
    ]
