# Generated by Django 3.2.12 on 2022-11-11 16:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('apps', '0002_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='TenantType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=150)),
            ],
        ),
        migrations.AddField(
            model_name='tenant',
            name='is_template',
            field=models.BooleanField(default=True),
        ),
        migrations.AlterField(
            model_name='tenant',
            name='name',
            field=models.CharField(max_length=100),
        ),
        migrations.AlterField(
            model_name='tenant',
            name='type',
            field=models.CharField(max_length=200),
        ),
    ]
