# Generated by Django 3.2.12 on 2023-02-13 17:15

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('billing', '0002_auto_20230209_1635'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='refund',
            options={'ordering': ['-date']},
        ),
    ]
