# Generated by Django 3.2.12 on 2022-12-10 13:24

from django.db import migrations, models
import multitenancy.users.models


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='tenantuser',
            options={'verbose_name': 'user profile', 'verbose_name_plural': 'user profiles'},
        ),
        migrations.AddField(
            model_name='tenantuser',
            name='avatar',
            field=models.ImageField(blank=True, upload_to=multitenancy.users.models.upload_avatar_to, verbose_name='profile picture'),
        ),
    ]
