# Generated by Django 3.2.12 on 2023-01-26 14:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0002_auto_20221210_1524'),
    ]

    operations = [
        migrations.AlterField(
            model_name='tenantuser',
            name='type',
            field=models.CharField(choices=[('Admin', 'Admin'), ('Staff', 'Staff'), ('Customer', 'Customer')], default='Customer', max_length=255, verbose_name='Type'),
        ),
    ]
