# Generated by Django 3.2.12 on 2022-11-13 09:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptions', '0003_auto_20221113_0746'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='plan',
            name='type',
        ),
        migrations.AddField(
            model_name='plan',
            name='description',
            field=models.TextField(blank=True, null=True),
        ),
    ]
