{% extends "portal/hod_template/base.html" %}



{% block main_content %}

  <h2 class="page-title text-dark">
    <i class="fa fa-groups-manager-groups-manager"></i>User Accounts Manager
  </h2>

<div class="container-fluid">
  <div class="row">
    <div class="col-md-6">
      <div class="list-group">
        <a href="{% url 'accounts_list' %}" class="list-group-item">
          <h4 class="list-group-item-heading">Accounts</h4>
          <p class="list-group-item-text">
            List of user accounts
          </p>
        </a>
        <a href="{% url 'groups_manager:member_list' %}" class="list-group-item">
          <h4 class="list-group-item-heading">Members</h4>
          <p class="list-group-item-text">
            Full list of members
          </p>
        </a>
      </div>
    </div>
    <div class="col-md-6">
      <div class="list-group">
        <a href="{% url 'groups_manager:group_type_list' %}" class="list-group-item">
          <h4 class="list-group-item-heading">Group Types</h4>
          <p class="list-group-item-text">
            Define types (i.e. "Organization")
          </p>
        </a>
        <a href="{% url 'groups_manager:group_entity_list' %}" class="list-group-item">
          <h4 class="list-group-item-heading">Group Entities</h4>
          <p class="list-group-item-text">
            Manage Group Entities (i.e. "Collaborators")
          </p>
        </a>
        <a href="{% url 'groups_manager:group_member_role_list' %}" class="list-group-item">
          <h4 class="list-group-item-heading">Group Member Roles</h4>
          <p class="list-group-item-text">
            User Roles within groups
          </p>
        </a>
      </div>
    </div>
  </div>
</div>

{% endblock main_content %}
