# Generated by Django 3.2.12 on 2023-01-24 17:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('apps', '0012_auto_20230107_1742'),
    ]

    operations = [
        migrations.AlterField(
            model_name='tenant',
            name='trail_duration',
            field=models.IntegerField(default=0),
        ),
    ]
