{% load bootstrap4 %}
<div class="modal fade" id="modal-lg">
    <div class="modal-dialog ">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title text-dark">Add New Feature</h4>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body">
                <form role="form" action="{% url 'create_feature' %}" method="post">
                    {% csrf_token %}
                    {% bootstrap_field form.name %}
                    {% bootstrap_field form.description %}
                    
                    
                    <input type="hidden" name="plan" value="{{plan.id}}"/>
                    <input type="hidden" name="plan_name" value="{{plan.slug}}"/>
                    <div class="modal-footer justify-content-between">
                        <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                        <button type="submit" class="btn btn-primary">Save changes</button>
                    </div>
                </form>
            </div>
        </div>
        <!-- /.modal-content -->
    </div>
    <!-- /.modal-dialog -->
</div>
<!-- /.modal -->