{% load bootstrap4 %}
<form method="post" class="ajax invite-form" data-replace=".invite-form" action="{% url "pinax_teams:team_invite" team.slug %}">
    {% csrf_token %}
    {% bootstrap_form invite_form %}
    <button class="btn btn-success">Invite</button>
</form>

