# Generated by Django 3.2.12 on 2023-01-31 19:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptions', '0011_auto_20230126_1655'),
    ]

    operations = [
        migrations.AlterField(
            model_name='subscription',
            name='subscription_duration',
            field=models.IntegerField(default=0),
        ),
    ]
