.settings-container{
    width: 100%;
    display: flex;
    flex-wrap: wrap;
    padding:2rem;
    justify-content: space-between;
    gap: 1rem;
}

.settings-block{
    border-radius: 5px;
    border: 1px solid black;
    padding: 15px 0 0 15px;
    
}

.settings-icon{
    color:aqua;
    font-size: 32px;
}