{% load static %}{% load multitenancy_tags %}
<!DOCTYPE html>
<html>

    <head>
        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <title>Client Area | {%block head_title%}{%endblock%}</title>
        <!-- Tell the browser to be responsive to screen width -->
        <meta name="viewport" content="width=device-width, initial-scale=1">

        <!-- Font Awesome -->
        <link rel="stylesheet" href="{% static "plugins/fontawesome/css/all.min.css" %}">
        <!-- Ionicons -->
        <link rel="stylesheet" href="https://code.ionicframework.com/ionicons/2.0.1/css/ionicons.min.css">
        
        
        <!-- Theme style -->
        <link rel="stylesheet" href="{% static "dist/css/adminlte.min.css" %}">
        <link rel="stylesheet" href="{% static "account/login.css" %}">
        <!-- Google Font: Source Sans Pro -->
        <link href="https://fonts.googleapis.com/css?family=Source+Sans+Pro:300,400,400i,700" rel="stylesheet">
    </head>

    <body class="hold-transition ">
    
            
            <!-- /.login-logo -->
            <div class="login-container">
                {% get_company_details as details %}
                
          {% block content %}
          {% endblock content %}
                <!-- /.login-card-body -->
            </div>
        <!-- /.login-box -->

        <!-- jQuery -->
        <script src="{% static "plugins/jquery/jquery.min.js" %}"></script>
        <!-- Bootstrap 4 -->
        <script src="{% static "plugins/bootstrap/js/bootstrap.bundle.min.js" %}"></script>
        <!-- AdminLTE App -->
        <script src="{% static "dist/js/adminlte.min.js" %}"></script>

    </body>

</html>