# Generated by Django 3.2.12 on 2023-02-08 06:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('settings', '0008_auto_20230208_0804'),
    ]

    operations = [
        migrations.AlterField(
            model_name='generalinfo',
            name='website',
            field=models.URLField(blank=True, default='https://example.com'),
        ),
    ]
