{% extends 'multitenancy/admin/base.html' %}
{%load static %}
{% block page_title %}Home{% endblock page_title %}
{% block welcome_message %}Welcome back, {{user.first_name}}{% endblock welcome_message %}
{% block main_content %}

    {% include "multitenancy/admin/publicUser/includes/stats.html" %}

{% endblock main_content %}

{% block custom_js %}

    
     <!-- ChartJS -->


{% endblock custom_js %}
    