# Generated by Django 3.2.12 on 2023-01-08 14:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptions', '0006_auto_20230107_1742'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='producttype',
            name='features',
        ),
        migrations.AddField(
            model_name='plan',
            name='features',
            field=models.ManyToManyField(to='subscriptions.ProductFeature'),
        ),
        migrations.AlterField(
            model_name='producttype',
            name='name',
            field=models.CharField(choices=[('tenant', 'Tenant App'), ('domain', 'Custom Domain'), ('third_party', '3rd party App')], default='tenant', max_length=115),
        ),
    ]
