# Generated by Django 3.2.12 on 2022-12-08 08:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('apps', '0008_auto_20221208_1033'),
    ]

    operations = [
        migrations.AddField(
            model_name='domain',
            name='has_custom',
            field=models.BooleanField(default=False),
        ),
    ]
