# Generated by Django 3.2.12 on 2022-10-17 13:13

from django.db import migrations, models
import django_tenants.postgresql_backend.base


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Domain',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('domain', models.CharField(db_index=True, max_length=253, unique=True)),
                ('is_primary', models.BooleanField(db_index=True, default=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DomainTld',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(choices=[('.co.za', '.co.za'), ('.com', '.com'), ('.org', '.org'), ('.org.za', '.org.za'), ('.net', '.net'), ('.africa', '.africa'), ('.web.za', '.web.za'), ('.net.za', '.net.za'), ('.joburg', '.joburg'), ('.capetown', '.capetown'), ('.durban', '.durban'), ('.za.com', '.za.com'), ('.sa.com', '.sa.com'), ('.mobi', '.mobi'), ('.info', '.info'), ('.biz', '.biz'), ('.name', '.name'), ('.co', '.co'), ('.cc', '.cc'), ('.co.uk', '.co.uk'), ('.org.uk', '.org.uk'), ('.gr', '.gr'), ('.me', '.me'), ('.mx', '.mx'), ('.us', '.us'), ('.tv', '.tv'), ('.vc', '.vc'), ('.ws', '.ws'), ('.academy', '.academy'), ('.agency', '.agency'), ('.art', '.art'), ('.bargains', '.bargains'), ('.bike', '.bike'), ('.build', '.build'), ('.builders', '.builders'), ('.camera', '.camera'), ('.camp', '.camp'), ('.careers', '.careers'), ('.center', '.center'), ('.city', '.city'), ('.clothing', '.clothing'), ('.cloud', '.cloud'), ('.club', '.club'), ('.codes', '.codes'), ('.coffee', '.coffee'), ('.company', '.company'), ('.computer', '.computer'), ('.construction', '.construction'), ('.consulting', '.consulting'), ('.contractors', '.contractors'), ('.diamonds', '.diamonds'), ('.directory', '.directory'), ('.design', '.design'), ('.domains', '.domains'), ('.education', '.education'), ('.email', '.email'), ('.energy', '.energy'), ('.engineering', '.engineering'), ('.enterprises', '.enterprises'), ('.enterprises', '.enterprises'), ('.equipment', '.equipment'), ('.estate', '.estate'), ('.farm', '.farm'), ('.florist', '.florist'), ('.fund', '.fund'), ('.gallery', '.gallery'), ('.glass', '.glass'), ('.global', '.global'), ('.graphics', '.graphics'), ('.green', '.green'), ('.guru', '.guru'), ('.healthcare', '.healthcare'), ('.holiday', '.holiday'), ('.one', '.one'), ('.online', '.online'), ('.marketing', '.marketing'), ('.ninja', '.ninja'), ('.rocks', '.rocks'), ('.run', '.run'), ('.services', '.services'), ('.solutions', '.solutions'), ('.space', '.space'), ('.store', '.store'), ('.tips', '.tips'), ('.tech', '.tech'), ('.trade', '.trade'), ('.university', '.university')], max_length=30, null=True)),
                ('price', models.DecimalField(decimal_places=2, max_digits=5)),
                ('transfer_price', models.DecimalField(decimal_places=2, default=50, max_digits=5)),
                ('period', models.IntegerField(default=1)),
            ],
        ),
        migrations.CreateModel(
            name='Packages',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(choices=[('public', 'public'), ('personal', 'personal'), ('premium', 'premium'), ('business', 'business')], default='personal', max_length=100)),
                ('price', models.DecimalField(decimal_places=2, default=75, max_digits=12, verbose_name='Price')),
            ],
        ),
        migrations.CreateModel(
            name='RegisteredDomain',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sld', models.CharField(max_length=250, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='Tenant',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False)),
                ('schema_name', models.CharField(db_index=True, max_length=63, unique=True, validators=[django_tenants.postgresql_backend.base._check_schema_name])),
                ('slug', models.SlugField(blank=True, verbose_name='Tenant URL Name')),
                ('type', models.CharField(default='personal', max_length=200)),
                ('name', models.CharField(default='name', max_length=100)),
                ('description', models.TextField(max_length=200)),
                ('on_trial', models.BooleanField(default=True)),
                ('created', models.DateField(auto_now_add=True)),
                ('modified', models.DateField(auto_now=True)),
            ],
        ),
    ]
