# Generated by Django 3.2.12 on 2022-10-07 08:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('profiles', '0003_auto_20221007_0951'),
    ]

    operations = [
        migrations.AddField(
            model_name='profile',
            name='display_profile',
            field=models.BooleanField(default=True),
        ),
    ]
